@@ -1,7 +1,7 @@
 import os, json, time, queue, inspect, functools, sys, signal
 from _collections import defaultdict
 from enum import Enum, unique
-
+from types import FunctionType, GeneratorType
 
 def is_Windows():
     return os.sep == '\\'
@@ -106,7 +106,6 @@ def cstring(s):
 
 
 def json_encode(data, utf8=False, indent=None):
-    from types import FunctionType
     if isinstance(data, FunctionType):
 
         def func(*args, **kwargs): 
@@ -670,6 +669,8 @@ def batches(listOfElement, batch_size):
 
 
 def is_same(list):
+    if isinstance(list, GeneratorType):
+        list = [*list]
     for i in range(1, len(list)):
         if list[i] != list[i - 1]:
             return False
